<?php
/**
 * Yii Hangman
 *
 * @author Marc Oliveras Galvez <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2021 Oligalma
 * @license GPL License
 */
 
class SiteController extends CController
{
	public $layout = '//layouts/column1';
    
    public function filters()
    {
        return array(
            'postOnly + guess',
        );
    }
    
    public function actionIndex()
    {
        $levels = array('0' => 'Easy game: you are allowed 10 misses.',
                        '1' => 'Medium game: you are allowed 5 misses.',
                        '2' => 'Hard game: you are allowed 3 misses.');
                        
        if(isset($_POST['level']))
        {
            $this->redirect(array('start', 'level' => $_POST['level'])); 
        }
        
        $this->render('index', array('levels' => $levels));
    }
    
    public function actionStart()
    {
        $lines = file(dirname(__FILE__) . '/../lib/dictionary.txt');      
        $word = $lines[rand(0, count($lines) - 1)];
        $word = substr($word, 0, strlen($word) - 1);

        Yii::app()->session['word'] = trim($word);
        Yii::app()->session['foundLetters'] = '';
        Yii::app()->session['win'] = null;
        
        $level = 0;
        if(isset($_GET['level']))
            $level = $_GET['level'];
        Yii::app()->session['level'] = $level;
        
        switch($level)
        {
            case 0: // Easy
                Yii::app()->session['lives'] = 10;
                break;
            case 1: // Medium
                Yii::app()->session['lives'] = 5;
                break;
            case 2: // Hard
                Yii::app()->session['lives'] = 3;
                break;                
        }
        
        Yii::app()->session['image'] = 0;
        
        $this->render('start', array('blankWord' => str_repeat(CHtml::tag('span',array('class' => 'guessed-letter'), '_'), strlen($word))));
    }
    
    /**
     * This is the action to handle external exceptions.
     */
    public function actionError()
    {
        if($error=Yii::app()->errorHandler->error)
        {
            if(Yii::app()->request->isAjaxRequest)
                echo $error['message'];
            else
                $this->render('error', $error);
        }
    }
    
    public function actionGuess()
    {
        $response = array();
        
        if(Yii::app()->session['win'] == null)
        {
            $letter = strtolower($_POST['letter']);
     
            if(strpos(strtolower(Yii::app()->session['word']), $letter) === false)
            {
                Yii::app()->session['lives'] -= 1;
                switch(Yii::app()->session['level'])
                {
                    case 0:
                        Yii::app()->session['image'] += 1;
                        break;
                    case 1:
                        Yii::app()->session['image'] += 2;
                        break;
                    case 2:
                            if(Yii::app()->session['image'] == 0)
                                Yii::app()->session['image'] = 3;
                            elseif(Yii::app()->session['image'] == 3)
                                Yii::app()->session['image'] = 6;
                            else
                                Yii::app()->session['image'] = 10;
                        break;
                }
                $response['image'] = Yii::app()->controller->module->assetsUrl . '/images/hangman/' . Yii::app()->session['image'] . '.jpg';
                
                if(Yii::app()->session['lives'] == 0)
                {
                    Yii::app()->session['win'] = false;
                    $response['word'] = 'The word was: ' . CHtml::tag('b',array(),Yii::app()->session['word']);
                }             
            }   
            else
            {
                Yii::app()->session['foundLetters'] .= $letter;
              
                $i = 0;
                $wordLetters = str_split(Yii::app()->session['word']);
                $foundLetters = str_split(Yii::app()->session['foundLetters']);
                foreach($wordLetters as $letter)
                {
                    $found = false;
                    
                    foreach($foundLetters as $letter2)
                    {
                        if($letter == $letter2)
                        {
                            $found = true;
                            break;
                        }
                    }
                    
                    if($found)
                        $i++;
                }  
                if($i == strlen(Yii::app()->session['word']))
                    Yii::app()->session['win'] = true;     
            }
        }

        $wordLetters = str_split(Yii::app()->session['word']);
        $foundLetters = str_split(Yii::app()->session['foundLetters']);
        $guessedWord = '';
        
        foreach($wordLetters as $letter)
        {
            $found = false;
            
            foreach($foundLetters as $letter2)
            {
                if($letter == $letter2)
                {
                    $found = true;
                    break;
                }
            }
            
            if($found)
                $guessedWord .= $letter;
            else
                $guessedWord .= CHtml::tag('span',array('class' => 'guessed-letter'), '_');
        }  
      
        $response['win'] = Yii::app()->session['win'];
        $response['lives'] = Yii::app()->session['lives'];
        $response['guessedWord'] = $guessedWord;
        
        echo json_encode($response);  
    }
}
